@@ -201,9 +201,52 @@ class RestAPI(object):
 		if success == True:
 			return r3sponse.success_response(f"Successfully canceled the subscription for user [{uid}] from plan [{plan}].")
 		else:
-			return r3sponse.error_response(f"Failed to cancel the subscription for user [{uid}] from plan [{plan}], error: {success}.")
+			if isinstance(success, str):
+				return r3sponse.error_response(f"Failed to cancel the subscription for user [{uid}] from plan [{plan}], error: {success}.")
+			else:
+				return r3sponse.error_response(f"Failed to cancel the subscription for user [{uid}] from plan [{plan}]")
 
 		#
+	def cancel_all_subscriptions(self, 
+		# the user's uid.
+		uid=None,
+	):
+
+		# get plans.
+		count = 0
+		for attempt in range(101):
+			response = self.get_subscription(uid=uid, active_only=True)
+			if response["error"] != None: 
+				return r3sponse.success_response(f"Successfully canceled {count} subscriptions from user [{uid}].")
+			subscription = response["subscription"]
+			
+			# iterate.
+			count = 0
+			for plan, info in subscription["plans"].items():
+
+				# delete.
+				try:
+					r = self.stripe.Subscription.delete(subscription_id)
+					success = r["status"] == "canceled"
+				except Exception as e: 
+					success = str(e)
+				if success != True:
+					response = self.__get_plan_by_plan_id__(plan)
+					if response["error"] == None:
+						plan = response["plan"]
+					if isinstance(success, str):
+						return r3sponse.error_response(f"Failed to cancel the subscription [{plan}] for user [{uid}], error: {success}.")
+					else:
+						return r3sponse.error_response(f"Failed to cancel the subscription [{plan}] for user [{uid}]")
+				else:
+					count += 1
+
+		# handle success.
+		return r3sponse.success_response(f"Successfully canceled {count} subscriptions from user [{uid}].")
+
+		#
+
+		
 	def get_customer_id(self, 
 		# the user's uid.
 		uid=None,
